@@ -9,6 +9,7 @@ from __future__ import absolute_import, print_function
 from ..compat import to_unicode
 from ..dml.fill import FillFormat
 from ..enum.dml import MSO_FILL
+from ..enum.lang import MSO_LANGUAGE_ID
 from ..enum.text import MSO_AUTO_SIZE, MSO_UNDERLINE
 from .fonts import FontFiles
 from .layout import TextFitter
@@ -315,6 +316,25 @@ class Font(object):
     def italic(self, value):
         self._rPr.i = value
 
+    @property
+    def language_id(self):
+        """
+        Get or set the language id of this |Font| instance. The language id
+        is a member of the :ref:`MsoLanguageId` enumeration. Assigning |None|
+        removes any language setting, the same behavior as assigning
+        `MSO_LANGUAGE_ID.NONE`.
+        """
+        lang = self._rPr.lang
+        if lang is None:
+            return MSO_LANGUAGE_ID.NONE
+        return self._rPr.lang
+
+    @language_id.setter
+    def language_id(self, value):
+        if value == MSO_LANGUAGE_ID.NONE:
+            value = None
+        self._rPr.lang = value
+
     @property
     def name(self):
         """
